/*
	Pasteboard.h
	Application Kit, Release 2.0
	Copyright (c) 1988, 1989, 1990, NeXT, Inc.  All rights reserved. 
*/

#import <Foundation/NSObject.h>
#import <objc/hashtable.h>
#import <machkit/NXData.h>
@class NSArray;
@class NSData;

/* standard Pasteboard types */

extern NSString *NSStringPboardType;
extern NSString *NSPostScriptPboardType;
extern NSString *NSTIFFPboardType;
extern NSString *NSRTFPboardType;
extern NSString *NSFilenamesPboardType;
extern NSString *NSTabularTextPboardType;
extern NSString *NSFontPboardType;
extern NSString *NSRulerPboardType;
extern NSString *NSFileContentsPboardType;
extern NSString *NSColorPboardType;

/* standard Pasteboard names */

extern NSString *NSGeneralPboard;
extern NSString *NSFontPboard;
extern NSString *NSRulerPboard;
extern NSString *NSFindPboard;
extern NSString *NSDragPboard;

extern NSString *NSCreateFilenamePboardType(NSString *fileType);
extern NSString *NSCreateFileContentsPboardType(NSString *fileType);
extern NSString *NSGetFileType(NSString *pboardType);
extern NSArray *NSGetFileTypes(NSArray *pboardTypes);

@interface NSPasteboard : NSObject
{
    id                  owner;
    int                 _realChangeCount;
    int                 _ourChangeCount;
    port_t              _server;
    id                 *_ownerArray;
    int			_numTypes;
    NSString *             *_typesArray;
    port_t              _client;
    BOOL               *_typesProvided;
    NSString *		_name;
    NSString *		_host;
    int			_serverVersion;
    unsigned int        _reservedPasteboard4;
}

+ generalPasteboard;
+ pasteboardWithName:(NSString *)name;
+ pasteboardWithUniqueName;

+ (NSArray *)typesFilterableTo:(NSString *)type;

+ pasteboardByFilteringFile:(NSString *)filename;
+ pasteboardByFilteringData:(NSData *)data ofType:(NSString *)type;
+ pasteboardByFilteringTypesInPasteboard:(NSPasteboard *)pboard;

- (NSString *)name;
- freeGlobally;

- (int)declareTypes:(NSArray *)newTypes owner:newOwner;
- (int)addTypes:(NSArray *)newTypes owner:newOwner;
- (int)changeCount;

- (BOOL)setData:(NSData *)theData forType:(NSString *)dataType;
- (NSData *)dataForType:(NSString *)dataType;

- (NSArray *)types;
- (NSString *)availableTypeFromArray:(NSArray *)types;

- (BOOL)setPropertyList:(id)plist forType:(NSString *)dataType;
- (id)propertyListForType:(NSString *)dataType;

- (BOOL)setString:(NSString *)string forType:(NSString *)dataType;
- (NSString *)stringForType:(NSString *)dataType;

@end

@interface NSPasteboard(FileContents)
- (BOOL)writeFileContents:(NSString *)filename;
- (NSString *)readFileContentsType:(NSString *)type toFile:(NSString *)filename;
@end

@interface NSObject(PasteboardOwner)
- pasteboard:sender provideDataForType:(NSString *)type;
- pasteboardChangedOwner:sender;
@end
