/*
	errors.h
	Application Kit, Release 2.0
	Copyright (c) 1988, 1989, 1990, NeXT, Inc.  All rights reserved. 
*/

/* Contains error numbers for the appkit. */

#ifndef APPKIT_ERROR_H
#define APPKIT_ERROR_H
#ifndef ERROR_H
#import <objc/error.h>
#endif ERROR_H

#define NSAppkitErrorBase 3000  /* Kit errors start here.  We get 1000 */
#define NSAppkitErrorBase 3000	   /* historical synonym */

#define NSApplicationErrorBase 10000000 /* app defined errors start here */
#define NSApplicationErrorBase 10000000	   /* historical synonym */

typedef enum _NXAppkitErrorTokens {
    NX_longLine	= NSAppkitErrorBase,  /* Text, line longer than 16384 chars */
    NX_nullSel,		/* Text, operation attempted on empty selection */
    NX_wordTablesWrite,		/* error while writing word tables */
    NX_wordTablesRead,		/* error while reading word tables */
    NX_textBadRead,		/* Text, error reading from file */
    NX_textBadWrite,		/* Text, error writing to file */
    NX_powerOff,		/* poweroff */
    NX_pasteboardComm,		/* communications prob with pbs server */
    NX_mallocError,		/* malloc problem */
    NX_printingComm,		/* sending to npd problem */
    NX_abortModal,		/* used to abort modal panels */
    NX_abortPrinting,		/* used to abort printing */
    NX_illegalSelector,		/* bogus selector passed to appkit */
    NX_appkitVMError,		/* error from vm_ call */
    NX_badRtfDirective,
    NX_badRtfFontTable,
    NX_badRtfStyleSheet,
    NX_newerTypedStream,
    NSTIFFException,
    NX_printPackageError,	/* problem loading the print package */
    NX_badRtfColorTable,
    NX_journalAborted,
    NX_draggingError,
    NX_colorUnknown,		/* NXColorList, unknown color name or number */
    NX_colorBadIO,		/* NXColorList file read/write error */
    NX_colorNotEditable,	/* Attempt to change noneditable color list */
    NSBadBitmapParametersException,		/* Inconsistent set of bitmap params */
    NX_windowServerComm,	/* Communications prob with the window server */
    NX_unavailableFont,		/* no default font could be found */
    NX_PPDIncludeNotFound,	/* Include file in PPD file not found */
    NX_PPDParseError,		/* PPD parsing error */
    NX_PPDIncludeStackOverflow,	/* PPD include files nested too deep */
    NX_PPDIncludeStackUnderflow,/* PPD include file nesting mismatched */
    NX_rtfPropOverflow		/* Rtf property stack overflow */
} NXAppkitErrorTokens;

/*
 * The proc called when raised exceptions bubble up to the [Application run]
 * level.
 */
typedef void NSErrorHandler(NXHandler *errorState);
extern NSErrorHandler *_NXTopLevelErrorHandler;
#define NSSetTopLevelErrorHandler( proc ) (_NXTopLevelErrorHandler = (proc))
#define NSErrorHandler() (_NXTopLevelErrorHandler)
extern NSErrorHandler NXDefaultTopLevelErrorHandler;

/*
 * Mechanism for reporting information on errors.
 */
typedef void NXErrorReporter(NXHandler *errorState);
extern void NXReportError(NXHandler *errorState); 
extern void NXRegisterErrorReporter(int min, int max, NXErrorReporter *proc); 
extern void NXRemoveErrorReporter(int code);

#endif APPKIT_ERROR_H
